@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9003';
+$XML::MyXML::VERSION = '0.9004';
 use strict;
 use warnings;
 use Carp;
@@ -476,7 +476,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9003';
+$XML::MyXML::Object::VERSION = '0.9004';
 use Carp;
 use Encode;
 
@@ -550,18 +550,22 @@ sub path {
 
 	my @path;
 	my $orig_path = $path;
-	$path = "/" . $path;
+	my $start_root = $path =~ m!^/!;
+	$path = "/" . $path		unless $start_root;
 	while (length $path) {
 		my $success = $path =~ s!^/((?:[^/\[]*)?(?:\[[^\]]+\])*)!!;
 		my $seg = $1;
 		if ($success) {
 			push @path, $seg;
 		} else {
-			die "Invalid path: $orig_path";
+			croak "Invalid XML path: $orig_path";
 		}
 	}
 
 	my $el = $self;
+	if ($start_root) {
+		$el->cmp_element(shift @path)	or return;
+	}
 	for (my $i = 0; $i < $#path; $i++) {
 		my $pathstep = $path[$i];
 		($el) = $el->children($pathstep);
@@ -692,7 +696,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9003
+version 0.9004
 
 =head1 SYNOPSIS
 
@@ -802,7 +806,7 @@ Optional flags: C<file>
 
 =head2 $obj->path("subtag1/subsubtag2[attr1=val1][attr2]/.../subsubsubtagX")
 
-Returns the element specified by the path as an XML::MyXML::Object object. When there are more than one tags with the specified name in the last step of the path, it will return all of them as an array. In scalar context will only return the first one. CSS3-style attribute selectors are allowed in the path next to the tagnames, for example: C<< p[class=big] >> will only return C<< <p> >> elements that contain an attribute called "class" with a value of "big". p[class] on the other hand will return p elements having a "class" attribute, but that attribute can have any value.
+Returns the element specified by the path as an XML::MyXML::Object object. When there are more than one tags with the specified name in the last step of the path, it will return all of them as an array. In scalar context will only return the first one. Simple CSS3-style attribute selectors are allowed in the path next to the tagnames, for example: C<< p[class=big] >> will only return C<< <p> >> elements that contain an attribute called "class" with a value of "big". p[class] on the other hand will return p elements having a "class" attribute, but that attribute can have any value.
 
 An example... To print the last names of all the students from the following XML, do:
 
@@ -841,6 +845,12 @@ An example... To print the last names of all the students from the following XML
         print $student->path('name/last')->value, "\n";
     }
 
+If you wish to describe the root element in the path as well, prepend it in the path with a slash like so:
+
+    if( $student->path('/student/name/last')->value eq $student->path('name/last')->value ) {
+        print "The two are identical", "\n";
+    }
+
 =head2 $obj->value
 
 When the element represented by the $obj object has only text contents, returns those contents as a string. If the $obj element has no contents, value will return an empty string.
